@@ -100,7 +100,7 @@ class _E2EConfigClient(object):
                                      .format(e, ' ({0})'.format(hint) if hint else ''))
 
         try:
-            Domain(domain_name=domain, zone_name=domain, record_name=self._compute_record_name(domain, record_name), record_ttl=record_ttl, record_type='TXT', content=record_content, api_key=self.api_key, api_token=self.api_token).check_domain_valid()
+            Domain(domain_name=domain, zone_name=domain, record_name=record_name, record_ttl=record_ttl, record_type='TXT', content=record_content, api_key=self.api_key, api_token=self.api_token).check_domain_valid()
             self._find_managed_zone_id(domain_name=domain, zone_name=domain, record_name=record_name, record_ttl=record_ttl, record_type='TXT', content=record_content, api_key=self.api_key, api_token=self.api_token)
         except errors as e:
             if str(e).startswith("Domain not found"):
@@ -112,7 +112,7 @@ class _E2EConfigClient(object):
 
         try:
             result = Domain(domain_name=domain, zone_name=domain, record_name=self._compute_record_name(domain, record_name), record_ttl=record_ttl, record_type='TXT', content=f'{record_content}', api_key=self.api_key, api_token=self.api_token).add_record() 
-            result_message = result['meassage']
+            result_message = result['message']
             logger.debug('Successfully added TXT record with id: %d', result_message)
         except Exception as e:
             logger.debug('Error adding TXT record using the e2e_client API: %s', e)
